[![Build Status](https://travis-ci.com/pysmo/pysmo.svg?branch=master)](https://travis-ci.com/pysmo/pysmo)
[![Documentation Status](https://readthedocs.org/projects/pysmo/badge/?version=latest)](https://pysmo.readthedocs.io/en/latest/?badge=latest)
[![codecov](https://codecov.io/gh/pysmo/pysmo/branch/master/graph/badge.svg?token=ZsHTBN4rxF)](https://codecov.io/gh/pysmo/pysmo)

Pysmo
=====

Python package to read/write/manipulate SAC (Seismic Analysis Code) files.

Documentation
-------------

The complete pysmo documentation is available at https://pysmo.readthedocs.io/

Contributors
------------

- Helio Tejedor